@@ -173,7 +173,8 @@ class InstallerEngine:
         print(" --> Cleaning up OEM config")
         self.update_progress(80, True, False, _("Cleaning OEM configuration"))
         os.system("rm -f /etc/lightdm/lightdm.conf.d/90-oem-config.conf")
-        os.system("apt-get remove --purge --yes --force-yes live-installer")
+        os.system("apt-get remove --purge --yes --force-yes `cat /etc/live-installer-oem-config.package-remove`")
+        os.system("rm -f /etc/live-installer-oem-config.package-remove")
         os.system("rm -f /target")
         os.system("touch /etc/live-installer-oem-config.done") # Leave a flag for mintsystem to clean up the OEM user account
 
@@ -249,12 +250,12 @@ class InstallerEngine:
             else:
                 num_copied = min(num_copied + 1, num_files)
                 percentage = int(float(num_copied) / float(num_files) * 100)
-                self.update_progress(percentage, False, False, _("Copying /%s") % line)
+                self.update_progress(percentage, False, False, _("Copying files..."))
         print("rsync exited with returncode: " + str(rsync.poll()))
 
         # chroot
         print(" --> Chrooting")
-        self.update_progress(10, False, False, _("Entering the system ..."))
+        self.update_progress(10, False, False, _("Entering the system..."))
         os.system("mount --bind /dev/ /target/dev/")
         os.system("mount --bind /dev/shm /target/dev/shm")
         os.system("mount --bind /dev/pts /target/dev/pts")
@@ -296,10 +297,11 @@ class InstallerEngine:
         with open("/run/live/medium/live/filesystem.packages-remove", "r") as fd:
             line = fd.read().replace('\n', ' ')
         if self.setup.oem_mode:
-            # in OEM mode don't remove live-installer just yet, only remove its menu item
-            line = line.replace('live-installer ', '')
+            # in OEM mode don't remove pkgs just yet
+            self.do_run_in_chroot(f'echo "{line}" > /etc/live-installer-oem-config.package-remove')
             self.do_run_in_chroot("rm -f /usr/share/applications/debian-installer-launcher.desktop")
-        self.do_run_in_chroot("apt-get remove --purge --yes --force-yes %s" % line)
+        else:
+            self.do_run_in_chroot("apt-get remove --purge --yes --force-yes %s" % line)
 
         # remove live leftovers
         self.do_run_in_chroot("rm -rf /etc/live")
@@ -324,7 +326,7 @@ class InstallerEngine:
     def mount_source(self):
         # Mount the installation media
         print(" --> Mounting partitions")
-        self.update_progress(50, False, False, _("Mounting %(partition)s on %(mountpoint)s") % {'partition':self.media, 'mountpoint':"/source/"})
+        self.update_progress(50, False, False, _("Mounting partitions..."))
         print(" ------ Mounting %s on %s" % (self.media, "/source/"))
         self.do_mount(self.media, "/source/", "squashfs", options="loop")
 
@@ -381,7 +383,7 @@ class InstallerEngine:
 
         # Wipe HDD
         if self.setup.badblocks:
-            self.update_progress(25, False, False, _("Filling %s with random data (please be patient, this can take hours...)") % self.setup.disk)
+            self.update_progress(25, False, False, _("Filling disk with random data (please be patient, this can take hours...)"))
             print(" --> Filling %s with random data" % self.setup.disk)
             os.system("badblocks -c 10240 -s -w -t random -v %s" % self.setup.disk)
 
@@ -433,7 +435,7 @@ class InstallerEngine:
         for partition in self.setup.partitions:
             if(partition.format_as is not None and partition.format_as != ""):
                 # report it. should grab the total count of filesystems to be formatted ..
-                self.update_progress(25, True, False, _("Formatting %(partition)s as %(format)s ...") % {'partition':partition.path, 'format':partition.format_as})
+                self.update_progress(25, True, False, _("Formatting partitions..."))
 
                 #Format it
                 if partition.format_as == "swap":
